/*
 * See the file "LICENSE" for the full license governing this code.
 */
package up;

/**
 * Null implementation of the
 * <code>TreeHandler</code> interface.
 *
 * @author Marco Kuhlmann <marco.kuhlmann@lingfil.uu.se>
 */
public class NullTreeHandler implements TreeHandler {

	/**
	 * The shared instance.
	 */
	private static NullTreeHandler instance = null;

	/**
	 * Private constructor to prevent instantiation.
	 */
	private NullTreeHandler() {
	}

	/**
	 * Returns the singleton instance of this class.
	 */
	public static NullTreeHandler getInstance() {
		if (instance == null) {
			instance = new NullTreeHandler();
		}
		return instance;
	}

	/**
	 * Does nothing.
	 */
	public void init() {
	}

	/**
	 * Does nothing.
	 *
	 * @param tree a tree
	 */
	public void next(Tree tree) {
	}

	/**
	 * Does nothing.
	 */
	public void exit() {
	}
}
