/*
 * See the file "LICENSE" for the full license governing this code.
 */
package up;

/**
 * A counter for trees.
 *
 * @author Marco Kuhlmann <marco.kuhlmann@lingfil.uu.se>
 */
public class TreeCounter extends DefaultTreeHandler {

    /**
     * The interval at which the current count is reported.
     */
    private final int interval;
    /**
     * The current count.
     */
    private int count;

    /**
     * Constructs a new counter.
     *
     * @param interval the interval at which the current count is reported
     */
    public TreeCounter(int interval) {
        super();
        this.interval = interval;
    }

    /**
     * Constructs a new counter that reports the current count after each 1000
     * trees.
     */
    public TreeCounter() {
        this(1000);
    }

    @Override
    public void init() {
        System.err.print("read:");
        super.init();
    }

    @Override
    public void next(Tree tree) {
        count++;
        if (count % interval == 0) {
            System.err.print(" ");
            System.err.print(count);
        }
        super.next(tree);
    }

    @Override
    public void exit() {
        super.exit();
        System.err.print(" ");
        System.err.println(count);
    }
}
